@@ -10,19 +10,27 @@ debugger.
 
 import socket
 
-from DebugProtocol import EOT
+from DebugUtilities import prepareJsonCommand
+
+try:
+    unicode
+except NameError:
+    unicode = str
+    raw_input = input
 
 
 def AsyncPendingWrite(file):
     """
     Module function to check for data to be written.
     
-    @param file The file object to be checked (file)
-    @return Flag indicating if there is data wating (int)
+    @param file The file object to be checked
+    @type file
+    @return Flag indicating if there is data waiting
+    @rtype int
     """
     try:
         pending = file.pendingWrite()
-    except:
+    except Exception:
         pending = 0
 
     return pending
@@ -33,25 +41,27 @@ class AsyncFile(object):
     Class wrapping a socket object with a file interface.
     """
     maxtries = 10
-    maxbuffersize = 1024 * 1024 * 4
     
     def __init__(self, sock, mode, name):
         """
         Constructor
         
         @param sock the socket object being wrapped
-        @param mode mode of this file (string)
-        @param name name of this file (string)
+        @type socket
+        @param mode mode of this file
+        @type str
+        @param name name of this file
+        @type str
         """
         # Initialise the attributes.
-        self.closed = 0
+        self.closed = False
         self.sock = sock
         self.mode = mode
         self.name = name
         self.nWriteErrors = 0
         self.encoding = "utf-8"
-
-        self.wpending = u''
+        
+        self.wpending = []
 
     def __checkMode(self, mode):
         """
@@ -60,98 +70,110 @@ class AsyncFile(object):
         This method checks, if an operation is permitted according to
         the mode of the file. If it is not, an IOError is raised.
         
-        @param mode the mode to be checked (string)
+        @param mode the mode to be checked
+        @type string
         @exception IOError raised to indicate a bad file descriptor
         """
         if mode != self.mode:
-            raise IOError('[Errno 9] Bad file descriptor')
-
-    def __nWrite(self, n):
-        """
-        Private method to write a specific number of pending bytes.
-        
-        @param n the number of bytes to be written (int)
-        """
-        if n:
-            try:
-                buf = "%s%s" % (self.wpending[:n], EOT)
-                try:
-                    buf = buf.encode('utf-8')
-                except (UnicodeEncodeError, UnicodeDecodeError):
-                    pass
-                self.sock.sendall(buf)
-                self.wpending = self.wpending[n:]
-                self.nWriteErrors = 0
-            except socket.error:
-                self.nWriteErrors += 1
-                if self.nWriteErrors > self.maxtries:
-                    self.wpending = u''  # delete all output
+            raise IOError((9, '[Errno 9] Bad file descriptor'))
 
     def pendingWrite(self):
         """
-        Public method that returns the number of bytes waiting to be written.
+        Public method that returns the number of strings waiting to be written.
         
-        @return the number of bytes to be written (int)
+        @return the number of strings to be written
+        @rtype int
         """
-        return self.wpending.rfind('\n') + 1
+        return len(self.wpending)
 
-    def close(self, closeit=0):
+    def close(self, closeit=False):
         """
         Public method to close the file.
         
         @param closeit flag to indicate a close ordered by the debugger code
-            (boolean)
+        @type bool
         """
         if closeit and not self.closed:
             self.flush()
             self.sock.close()
-            self.closed = 1
+            self.closed = True
 
     def flush(self):
         """
-        Public method to write all pending bytes.
+        Public method to write all pending entries.
         """
-        self.__nWrite(len(self.wpending))
+        while self.wpending:
+            try:
+                buf = self.wpending.pop(0)
+            except IndexError:
+                break
+            
+            try:
+                try:
+                    buf = buf.encode('utf-8', 'backslashreplace')
+                except (UnicodeEncodeError, UnicodeDecodeError):
+                    pass
+                self.sock.sendall(buf)
+                self.nWriteErrors = 0
+            except socket.error:
+                self.nWriteErrors += 1
+                if self.nWriteErrors > self.maxtries:
+                    self.wpending = []    # delete all output
 
     def isatty(self):
         """
         Public method to indicate whether a tty interface is supported.
         
         @return always false
+        @rtype bool
         """
-        return 0
+        return False
 
     def fileno(self):
         """
         Public method returning the file number.
         
-        @return file number (int)
+        @return file number
+        @rtype int
         """
         try:
             return self.sock.fileno()
         except socket.error:
             return -1
 
+    def readable(self):
+        """
+        Public method to check, if the stream is readable.
+        
+        @return flag indicating a readable stream
+        @rtype bool
+        """
+        return self.mode == "r"
+    
     def read_p(self, size=-1):
         """
         Public method to read bytes from this file.
         
-        @param size maximum number of bytes to be read (int)
-        @return the bytes read (any)
+        @param size maximum number of bytes to be read
+        @type int
+        @return the bytes read
+        @rtype str
         """
         self.__checkMode('r')
 
         if size < 0:
             size = 20000
 
-        return self.sock.recv(size).decode('utf8')
+        return self.sock.recv(size).decode('utf8', 'backslashreplace')
 
     def read(self, size=-1):
         """
         Public method to read bytes from this file.
         
-        @param size maximum number of bytes to be read (int)
-        @return the bytes read (any)
+        @param size maximum number of bytes to be read
+        @type int
+        @return the bytes read
+        @rtype str
         """
         self.__checkMode('r')
 
@@ -167,8 +189,10 @@ class AsyncFile(object):
         <b>Note</b>: This method will not block and may return
         only a part of a line if that is all that is available.
         
-        @param size maximum number of bytes to be read (int)
-        @return one line of text up to size bytes (string)
+        @param size maximum number of bytes to be read
+        @type int
+        @return one line of text up to size bytes
+        @rtype str
         """
         self.__checkMode('r')
 
@@ -181,7 +205,7 @@ class AsyncFile(object):
         # read a line at a time.
         line = self.sock.recv(size, socket.MSG_PEEK)
 
-        eol = line.find('\n')
+        eol = line.find(b'\n')
 
         if eol >= 0:
             size = eol + 1
@@ -189,14 +213,16 @@ class AsyncFile(object):
             size = len(line)
 
         # Now we know how big the line is, read it for real.
-        return self.sock.recv(size).decode('utf8')
+        return self.sock.recv(size).decode('utf8', 'backslashreplace')
 
     def readlines(self, sizehint=-1):
         """
         Public method to read all lines from this file.
         
-        @param sizehint hint of the numbers of bytes to be read (int)
-        @return list of lines read (list of strings)
+        @param sizehint hint of the numbers of bytes to be read
+        @type int
+        @return list of lines read
+        @rtype list of str
         """
         self.__checkMode('r')
 
@@ -224,8 +250,10 @@ class AsyncFile(object):
         """
         Public method to read one line from this file.
         
-        @param sizehint hint of the numbers of bytes to be read (int)
-        @return one line read (string)
+        @param sizehint hint of the numbers of bytes to be read
+        @type int
+        @return one line read
+        @rtype str
         """
         self.__checkMode('r')
 
@@ -233,17 +261,28 @@ class AsyncFile(object):
         if sizehint >= 0:
             line = line[:sizehint]
         return line
+    
+    def seekable(self):
+        """
+        Public method to check, if the stream is seekable.
         
+        @return flag indicating a seekable stream
+        @rtype bool
+        """
+        return False
+    
     def seek(self, offset, whence=0):
         """
         Public method to move the filepointer.
         
-        @param offset offset to seek for
-        @param whence where to seek from
+        @param offset offset to move the filepointer to
+        @type int
+        @param whence position the offset relates to
+        @type int
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError('[Errno 29] Illegal seek')
+        raise IOError((29, '[Errno 29] Illegal seek'))
 
     def tell(self):
         """
@@ -252,53 +291,63 @@ class AsyncFile(object):
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError('[Errno 29] Illegal seek')
+        raise IOError((29, '[Errno 29] Illegal seek'))
 
     def truncate(self, size=-1):
         """
         Public method to truncate the file.
         
-        @param size size to truncate to (integer)
+        @param size size to truncate to
+        @type int
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError('[Errno 29] Illegal seek')
+        raise IOError((29, '[Errno 29] Illegal seek'))
 
+    def writable(self):
+        """
+        Public method to check, if a stream is writable.
+        
+        @return flag indicating a writable stream
+        @rtype bool
+        """
+        return self.mode == "w"
+    
     def write(self, s):
         """
         Public method to write a string to the file.
         
-        @param s bytes to be written (string)
-        @exception socket.error raised to indicate too many send attempts
+        @param s text to be written
+        @type str
+        """
+        self.__checkMode('w')
+        
+        cmd = prepareJsonCommand("ClientOutput", {
+            "text": s,
+        })
+        self.wpending.append(cmd)
+        self.flush()
+    
+    def write_p(self, s):
+        """
+        Public method to write a json-rpc 2.0 coded string to the file.
+        
+        @param s text to be written
+        @type str
         """
         self.__checkMode('w')
-        tries = 0
-        if not self.wpending:
-            self.wpending = s
-        elif type(self.wpending) != type(s) or \
-                len(self.wpending) + len(s) > self.maxbuffersize:
-            # flush wpending so that different string types are not
-            # concatenated
-            while self.wpending:
-                # if we have a persistent error in sending the data, an
-                # exception will be raised in __nWrite
-                self.flush()
-                tries += 1
-                if tries > self.maxtries:
-                    raise socket.error("Too many attempts to send data")
-            self.wpending = s
-        else:
-            self.wpending += s
-        self.__nWrite(self.pendingWrite())
 
-    def writelines(self, list):
+        self.wpending.append(s)
+        self.flush()
+
+    def writelines(self, lines):
         """
         Public method to write a list of strings to the file.
         
-        @param list the list to be written (list of string)
+        @param lines list of texts to be written
+        @type list of str
         """
-        map(self.write, list)
+        self.write("".join(lines))
 
 #
-# eflag: FileType = Python2
-# eflag: noqa = M601, M702
+# eflag: noqa = M702
