@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -143,6 +143,12 @@ class PluginManager(QObject):
             self.__sslErrorHandler = E5SslErrorHandler(self)
             self.__networkManager.sslErrors.connect(self.__sslErrors)
         self.__replies = []
+        
+        try:
+            self.__ui.onlineStateChanged.connect(self.__onlineStateChanged)
+        except AttributeError:
+            # it was not called from eric
+            pass
     
     def finalizeSetup(self):
         """
@@ -801,6 +807,9 @@ class PluginManager(QObject):
             module = self.__failedModules[name]
             autoactivate = False
             active = False
+        elif "_" in name:
+            # try stripping of a postfix
+            return self.getPluginDetails(name.rsplit("_", 1)[0])
         else:
             # should not happen
             return None
@@ -894,6 +903,23 @@ class PluginManager(QObject):
         
         return apis
         
+    def getPluginQtHelpFiles(self):
+        """
+        Public method to get the list of QtHelp documentation files provided
+        by a plug-in.
+        
+        @return dictionary with documentation type as key and list of files
+            as value
+        @rtype dict (key: str, value: list of str)
+        """
+        helpFiles = {}
+        for module in list(self.__activeModules.values()) + \
+                list(self.__onDemandActiveModules.values()):
+            if hasattr(module, "helpFiles"):
+                helpFiles.update(module.helpFiles())
+        
+        return helpFiles
+        
     def getPluginExeDisplayData(self):
         """
         Public method to get data to display information about a plugins
@@ -1052,7 +1078,7 @@ class PluginManager(QObject):
                 self.deactivatePlugin(name, True)
     
     ########################################################################
-    ## Methods creation of the plug-ins download directory
+    ## Methods for the creation of the plug-ins download directory
     ########################################################################
     
     def __checkPluginsDownloadDirectory(self):
@@ -1097,12 +1123,22 @@ class PluginManager(QObject):
     ## Methods for automatic plug-in update check below
     ########################################################################
     
+    def __onlineStateChanged(self, online):
+        """
+        Private slot handling changes in online state.
+        
+        @param online flag indicating the online state
+        @type bool
+        """
+        if online:
+            self.checkPluginUpdatesAvailable()
+    
     def checkPluginUpdatesAvailable(self):
         """
         Public method to check the availability of updates of plug-ins.
         """
         period = Preferences.getPluginManager("UpdatesCheckInterval")
-        if period == 0:
+        if period == 0 or not self.__ui.isOnline():
             return
         elif period in [1, 2, 3]:
             lastModified = QFileInfo(self.pluginRepositoryFile).lastModified()
@@ -1148,6 +1184,7 @@ class PluginManager(QObject):
                 ).format(Preferences.getUI("PluginRepositoryUrl6"),
                          reply.errorString())
             )
+            reply.deleteLater()
             return
         
         ioDevice = QFile(self.pluginRepositoryFile + ".tmp")
@@ -1157,6 +1194,7 @@ class PluginManager(QObject):
         if QFile.exists(self.pluginRepositoryFile):
             QFile.remove(self.pluginRepositoryFile)
         ioDevice.rename(self.pluginRepositoryFile)
+        reply.deleteLater()
         
         if os.path.exists(self.pluginRepositoryFile):
             f = QFile(self.pluginRepositoryFile)
@@ -1253,3 +1291,6 @@ class PluginManager(QObject):
         ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
         if ignored == E5SslErrorHandler.NotIgnored:
             self.__downloadCancelled = True
+
+#
+# eflag: noqa = M801
