@@ -212,8 +212,9 @@ def main():
         elif k in ["-c", "--style-sheet"]:
             stylesheetFile = v
         elif k in ["-t", "--extension"]:
-            if not v.startswith("."):
-                v = ".{0}".format(v)
+            if v.strip():
+                if not v.startswith("."):
+                    v = ".{0}".format(v)
             supportedExtensions.append(v)
         elif k == "--eol":
             if v.lower() == "cr":
@@ -268,10 +269,6 @@ def main():
             qtHelpTitle == ""):
         usage()
     
-    if qtHelpCreation:
-        from PyQt5.QtCore import QCoreApplication
-        app = QCoreApplication(sys.argv)    # __IGNORE_WARNING__
-
     input = output = 0
     basename = ""
 
@@ -430,3 +427,6 @@ def main():
 
 if __name__ == '__main__':
     main()
+
+#
+# eflag: noqa = M801
